@@ -128,7 +128,7 @@ COUNTRIES = (
     ('LB', _(u'Lebanon')),
     ('LS', _(u'Lesotho')),
     ('LR', _(u'Liberia')),
-    ('LY', _(u'Libyan Arab Jamahiriya')),
+    ('LY', _(u'Libya')),
     ('LI', _(u'Liechtenstein')),
     ('LT', _(u'Lithuania')),
     ('LU', _(u'Luxembourg')),
@@ -388,7 +388,7 @@ COUNTRIES_PLUS = (
     ('LB', _(u'Lebanon')),
     ('LS', _(u'Lesotho')),
     ('LR', _(u'Liberia')),
-    ('LY', _(u'Libyan Arab Jamahiriya')),
+    ('LY', _(u'Libya')),
     ('LI', _(u'Liechtenstein')),
     ('LT', _(u'Lithuania')),
     ('LU', _(u'Luxembourg')),
@@ -651,7 +651,7 @@ OFFICIAL_COUNTRIES = {
     'LB': u'LEBANON',
     'LS': u'LESOTHO',
     'LR': u'LIBERIA',
-    'LY': u'LIBYAN ARAB JAMAHIRIYA',
+    'LY': u'LIBYA',
     'LI': u'LIECHTENSTEIN',
     'LT': u'LITHUANIA',
     'LU': u'LUXEMBOURG',
